    	import particles_background_effect from '@/glamour/background_effects/particles/money.vue'

    	this.vantaEffect = FOG ({
    		THREE: THREE,
    		el: foundation,
    		mouseControls: true,
    		touchControls: true,
    		gyroControls: false,
    		minHeight: 200.00,
    		minWidth: 200.00,
    		highlightColor: 0xff00b4,
    		midtoneColor: 0xced926,
    		lowlightColor: 0x24286e,
    		baseColor: 0xf0e0e3,
    		blurFactor: 0.32,
    		speed: 0.60,
    		zoom: 2.70
    	})

    	this.vantaEffect.destroy ()